@@ -7,26 +7,28 @@
 import requests
 import time
 import uuid
-# import cv2
 from cv2 import imdecode, imshow, IMREAD_COLOR, waitKey, destroyAllWindows
 import numpy as np
-from urllib import request
+from loguru import logger
 
 
 class Token:
     code_url = ""
 
     def __init__(self):
+        # 初始化
         self.makeCodeUrl()
 
     def makeCodeUrl(self):
+        # 生成coder的url
         self.uuid_str = str(uuid.uuid4())
         timestamp = time.time()
         self.code_url = f"https://api.icaodong.com/manager/sysuser/imagecode?uuid={self.uuid_str}&time={int(timestamp*100)}"
 
     def openCode(self):
-        resp = request.urlopen(self.code_url)
-        image = np.asarray(bytearray(resp.read()), dtype="uint8")
+        # 弹出验证码
+        resp = requests.get(self.code_url)
+        image = np.asarray(bytearray(resp.content), dtype="uint8")
         image = imdecode(image, IMREAD_COLOR)
         imshow('验证码', image)
         key = waitKey(0)
@@ -36,8 +38,18 @@ class Token:
         else:
             self.openCode()
 
-    def get(self, tenantId, acc, pwd, acc_type=0):
-        # acc_type=0表示个人管理员=1表示企业管理员
+    def get(self, tenantId: int, acc: str, pwd: str, acc_type: int = 0) -> str:
+        """取得token的方法
+
+        Args:
+            tenantId (int): [草动租户ID]
+            acc (str): [账号]
+            pwd (str): [密码]
+            acc_type (int, optional): [账号类型，0表示个人管理员1表示企业管理员]. Defaults to 0.
+
+        Returns:
+            [str]: [返回token字符串或者None]
+        """
         self.openCode()
         data = {
             "tenantId": tenantId,
@@ -54,11 +66,20 @@ class Token:
             response_json = response.json()
             status = response_json.get('status')
             if status == 200:
+                # 成功
                 token = response_json.get("data").get("token")
-                print(f"token is {token}")
+                logger.success(f"token is {token}")
                 return token
             else:
-                print(url, data, response_json)
+                # 失败
+                msg = response_json.get("message")
+                logger.error(dict(
+                    msg=msg,
+                    url=url,
+                    data=data,
+                    response_json=response_json
+                ))
+                # 失败重试
                 self.get(
                     tenantId=tenantId,
                     acc=acc,
@@ -68,7 +89,7 @@ class Token:
 
 def testcase():
     t = Token()
-    t.get(508, "13801587423", "cd123456")
+    t.get(10310, "13801587423", "xtep123456", 1)
 
 
 if __name__ == "__main__":
